#include "mainwindow.h"
#include "ui_mainwindow.h"

MainWindow::MainWindow(QWidget *parent): QMainWindow(parent), ui(new Ui::MainWindow)
{
  version=0;
  infoversion = "1.04";
  infodatum = "28.01.2024";
  #ifdef Q_OS_WIN
  infotext = tr("<h2>QTWinmWMeter</h2>"
                "<p><B>Version %1</B>\t\t%2 </p>"
                "<p>Entwickelt unter Linux mit QT5</p>"
                "<p>(c) Andreas Lindenau DL4JAL<br>"
                "DL4JAL@t-online.de<br>"
                "http://www.dl4jal.de</p>").arg(infoversion).arg(infodatum);
  #else
  infotext = tr("<h2>QTLinmWMeter</h2>"
                "<p><B>Version %1</B>\t\t%2 </p>"
                "<p>Entwickelt unter Linux mit QT5</p>"
                "<p>(c) Andreas Lindenau DL4JAL<br>"
                "DL4JAL@t-online.de<br>"
                "http://www.dl4jal.de</p>").arg(infoversion).arg(infodatum);

  #endif
  /*****************************************************************************/
  picmodem = new Modem();
  QObject::connect( picmodem, SIGNAL(setTtyText(QString)), this, SLOT(setAText(QString)));
  /*****************************************************************************/
  openttytimer = new QTimer(this);
  QObject::connect(openttytimer, SIGNAL(timeout()), this, SLOT(fopentty() ));
  rs232rxtimer = new QTimer(this);
  //Signal vom befantworttimer (Auslesen der RS232)
  QObject::connect(rs232rxtimer, SIGNAL(timeout()), this, SLOT(rs232rxtimerstop() ));
  delaytimer = new QTimer(this);
  QObject::connect(delaytimer, SIGNAL(timeout()), this, SLOT(delaytimerstop() ));

#ifdef Q_OS_WIN
  int i;
  QString qs;
  for(i=1;i<=60;i++){
    qs.sprintf("COM%i",i);
    listtty.append(qs);
  }
#else
  listtty.append(schnittstelle1);// /dev/ttyS0 Test mit NWT01
  listtty.append(schnittstelle5);// USB Schnittstellen
  listtty.append(schnittstelle6);
  listtty.append(schnittstelle7);
  listtty.append(schnittstelle8);
#endif
  ui->setupUi(this);

  ui->label_ad8307_dbm->setText("dBm");
  ui->label_ad8307_watt->setText("Watt");
  ui->label_ad8307_volt->setText("Volt");
  ui->label_ad8361_dbm->setText("dBm");
  ui->label_ad8361_watt->setText("Watt");
  ui->label_ad8361_volt->setText("Volt");
  ui->button_att->setEnabled(false);
  ui->button_mfrq->setEnabled(false);
  ui->gb_att_extern->setEnabled(false);
  ui->gb_messfrq->setEnabled(false);
  ui->gb_ad8307->setEnabled(false);
  ui->gb_ad8361->setEnabled(false);
  ui->gb_offset->setEnabled(false);
  bdbm12=false;
}


MainWindow::~MainWindow()
{
  delete ui;
}

void MainWindow::closeEvent(QCloseEvent *event)
{
  writeSettings();//alle Einstellungen speichern
  picmodem->writeLine("@c;"); //HW zum Senden ausschalten
  delay(100);
  picmodem->writeLine("@c;"); //HW zum Senden ausschalten
  delay(100);
  picmodem->writeLine("@c;"); //HW zum Senden ausschalten
  delay(100);
  picmodem->closetty();
  delete picmodem;
  event->accept();//Beenden erlauben
}

void MainWindow::fopentty(){
  int gelesen;
  QString qs;
  QString qversion;

  openttytimer->stop();
  if(bvantwort){
    bvantwort = false;
    gelesen = picmodem->readttybuffer(rxbuffer, 20);
    if(gelesen == 7){
      geraet=rxbuffer[1];
      geraet.append(rxbuffer[2]);
      qversion=rxbuffer[3];
      qversion.append(rxbuffer[4]);
      qversion.append(rxbuffer[5]);
      version = qversion.toInt();
      bvantwort = false;
      if((geraet == "vW")and(version >= 104)){
        bhwgefunden = true;
        openttytimer->stop(); //Suchen der Schnittstelle bendet
        statusBar()->showMessage(tr("HW gefunden an: ") + srs232);
        picmodem->writeLine("@o;"); //HW zum Senden einschalten
        setAText(srs232);
        clrrxbuffer();
        rs232rxtimer->start(200);//Ausgabe der HW auslesen
      }else{
        idtty++;
        if(idtty > (listtty.count()-1))idtty = 0;
        openttytimer->start(200); //Suchen der Schnittstelle
        picmodem->closetty();
        rs232isopen = false;
      }
    }else{
      idtty++;
      if(idtty > (listtty.count()-1))idtty = 0;
      openttytimer->start(200); //Suchen der Schnittstelle
      picmodem->closetty();
      rs232isopen = false;
    }
  }else{
    if(!rs232isopen){
      srs232 = listtty.at(idtty);
      statusBar()->showMessage(tr("Suche HW :","fopentty") + srs232);
      //qDebug(qPrintable(srs232));
      //qDebug("%i",idtty);
      rs232isopen = picmodem->opentty(srs232);
      if(rs232isopen){
        // Anforderung @v; (Firmware abfrage)
        //qDebug() << "open";
        picmodem->writeLine("@v;");
        //qDebug("open");
        bvantwort = true;
        openttytimer->start(300); //Suchen der HW
      }else{
        idtty++;
        if(idtty > (listtty.count()-1))idtty = 0;
        openttytimer->start(100); //Suchen der Schnittstelle
        bvantwort = false;
        picmodem->closetty();
      }
    }
  }
}

void MainWindow::rs232rxtimerstop()
{
  unsigned char abuffer[1000];
  QString qsbef, qs;
  int a, i, j, k, pos1=0;
  uchar u;
  double d, mwatt, volt;
  bool ok;
  QString str_dbmmax = tr(
        "<b><u>ACHTUNG!!!</u></b><br>"
        "<br>"
        "Der maximale dBm-Pegel<br>"
        "<b>%1 dBm</b><br>"
        "wurde &uuml;berschritten!!!"
        ,"tooltip text");



  rs232rxtimer->stop();
  a = picmodem->readttybuffer(abuffer, 1000);//a = Anzahl der zu holenden Bytes
  //qDebug()<<"a: "<<a;
  if((idxbufferwrite + a) >= 1000){
    idxbufferwrite=0;
    idxbufferread=0;
  }
  if(a > 0){
    for(i=0, j=idxbufferwrite; i<a; i++, j++){
      rxbuffer[j] = abuffer[i]; //Die gelesenen Daten in den richtigen Buffer kopieren
    }
    idxbufferwrite = idxbufferwrite + a; // und den Index auf die richtige Stelle setzen
  }
  while(idxbufferread != idxbufferwrite){
    if(rxbuffer[idxbufferread] == '@'){
      befehlanfang=true;
      pos1=idxbufferread;
      //qDebug()<<"anfang " << pos1;
    }
    if(befehlanfang)
      if(rxbuffer[idxbufferread] == ';'){
        befehlende=true;
        //pos2=idxbufferread;
        //qDebug()<<"ende " << pos2;
      }
    qsbefehl.append(rxbuffer[idxbufferread]);
    //qDebug()<<qsbefehl;
    idxbufferread++;
    //Kompletten Befehle erkannt
    if(befehlanfang and befehlende){
      qsbef=qsbefehl.mid(pos1,2);
      //qDebug()<<qsbef;
      if(qsbef=="@a"){
        qs=qsbefehl.mid(pos1+2,11);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qs;
        d=qs.toDouble(&ok);
        if(ok){
          ui->gb_ad8307->setEnabled(true);
          dbmad8307=d;
          qs = "%1 dBm";
          if(bdbm12){
            qs = qs.arg(dbmad8307, 0,'f',1);
          }else{
            qs = qs.arg(dbmad8307, 0,'f',2);
          }
          //qDebug()<<qs;
          ui->label_ad8307_dbm->setText(qs);
          mwatt = pow(10.0 , d/10.0);
          volt = sqrt(mwatt * 0.05);
          qs=mwatt2str(mwatt);
          ui->label_ad8307_watt->setText(qs);
          qs=volt2str(volt);
          ui->label_ad8307_volt->setText(qs);
        }
        clrrxbuffer();
      }
      if(qsbef=="@e"){
        qs=qsbefehl.mid(pos1+2,3);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qs;
        d=qs.toDouble(&ok);
        if(ok and (ui->button_att->isEnabled()==false)){
          d=d/10.0;
          ui->gb_att_extern->setEnabled(true);
          ui->doubleSpinBox->setValue(d);
          ui->button_att->setEnabled(false);
        }
        befehlanfang=false;
        befehlende=false;
      }
      if(qsbef=="@f"){
        //qDebug()<<qsbef;
        qs=qsbefehl.mid(pos1+2,3);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qs;
        k=qs.toInt(&ok);
        if(ok and (ui->button_mfrq->isEnabled()==false)){
          ui->gb_messfrq->setEnabled(true);
          ui->spinBox->setValue(k);
          ui->button_mfrq->setEnabled(false);
        }
        befehlanfang=false;
        befehlende=false;
      }
      if(qsbef=="@b"){
        qs=qsbefehl.mid(pos1+2,11);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qs;

        d=qs.toDouble(&ok);
        if(ok){
          ui->gb_ad8361->setEnabled(true);
          dbmad8361=d;
        }
        if((dbmad8307 < -10.0) or (dbmad8361 < -10.0)){
          ui->label_ad8361_dbm->setText("< -10,0 dBm");
          ui->label_ad8361_watt->setText("----------");
          ui->label_ad8361_volt->setText("----------");
        }else{
          qs = "%1 dBm";
          //qDebug()<<qs;
          if(bdbm12){
            qs = qs.arg(dbmad8361, 0,'f',2);
          }else{
            qs = qs.arg(dbmad8361, 0,'f',3);
          }
          ui->label_ad8361_dbm->setText(qs);
          //clrrxbuffer();
          mwatt = pow(10.0 , d/10.0);
          volt = sqrt(mwatt * 0.05);
          qs=mwatt2str(mwatt);
          ui->label_ad8361_watt->setText(qs);
          qs=volt2str(volt);
          ui->label_ad8361_volt->setText(qs);
        }
        befehlanfang=false;
        befehlende=false;
      }
      if(qsbef=="@k"){
        qs=qsbefehl.mid(pos1+2,11);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qs;
        d=qs.toDouble(&ok);
        if(ok){
          ui->gb_offset->setEnabled(true);
          qs = "%1 dB";
          qs = qs.arg(d, 0,'f',7);
          //qDebug()<<qs;
          ui->label_ad8307_wert->setText(qs);
        }
        befehlanfang=false;
        befehlende=false;
      }
      if(qsbef=="@l"){
        qs=qsbefehl.mid(pos1+2,11);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qs;
        d=qs.toDouble(&ok);
        if(ok){
          ui->gb_offset->setEnabled(true);
          qs = "%1 dB";
          qs = qs.arg(d, 0,'f',7);
          //qDebug()<<qs;
          ui->label_ad8361_wert->setText(qs);
        }
        befehlanfang=false;
        befehlende=false;
      }
      if(qsbef=="@m"){
        qs=qsbefehl.mid(pos1+2,11);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qs;
        d=qs.toDouble(&ok);
        if(ok){
          ui->gb_offset->setEnabled(true);
          qs = "%1 dB";
          qs = qs.arg(d, 0,'f',2);
//          qs.sprintf("%2.2f dB",d);
          //qDebug()<<qs;
          ui->label_frq_wert->setText(qs);
        }
        befehlanfang=false;
        befehlende=false;
      }
      if(qsbef=="@d"){
        qs=qsbefehl.mid(pos1+2,3);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qsbefehl;
        u=qs.toInt(&ok);
        if(ok){
          //Bit 1 von Flag1 auswerten
          if((u & 2) == 2){
            bdbm12 = true;
          }else{
            bdbm12 = false;
          }
        }
        befehlanfang=false;
        befehlende=false;
      }
      if(qsbef=="@g"){
        qs=qsbefehl.mid(pos1+2,3);
        qs.replace(',','.');
        qs.remove(' ');
        //qDebug()<<qsbefehl;
        u=qs.toInt(&ok);
        if(ok){
          dbmmax = u;
          str_dbmmax=str_dbmmax.arg(dbmmax);
          QMessageBox::critical(this, tr("AD8307 oder AD8361","in Dialogbox"),str_dbmmax);
        }
        befehlanfang=false;
        befehlende=false;
      }   }
  }
  rs232rxtimer->start();
}

void MainWindow::setAText(QString stty){
  QString qs, qs1;
#ifdef Q_OS_WIN
  qs = tr("Mini mW-Meter-Windows ");
#else
  qs = tr("Mini mW-Meter-Linux ");
#endif
  QString fwversion = tr("HW nicht gefunden");
  if(version >= 104){
    int f1, f2;
    f1 = version/100;
    f2 = version-(version/100)*100;
    fwversion = "FW:%1.%2";
    fwversion = fwversion.arg(f1).arg(f2,2,10, QLatin1Char('0'));
  }
  QString astty;
  astty = qs + "[" + stty + "-" + fwversion + "]";
  setWindowTitle(astty);
}

void MainWindow::clrrxbuffer(){
  unsigned char abuffer[100];

  if (rs232isopen){
    picmodem->readttybuffer(abuffer, 100);//PC Buffer maximal auslesen
  }
  for(int i=0;i<100;i++)rxbuffer[i]=0; //gesamten rs232buffer loeschen
  idxbufferread=0;
  idxbufferwrite=0;
  qsbefehl="";
  befehlanfang=false;
  befehlende=false;
}

void MainWindow::delay(int zeit)
{
  if(zeit == 0)return;
  tstop = false;
  delaytimer->start(zeit);
  while(!tstop){
    qApp->processEvents();//Austritt aus der Funktion fuer Events
  }
}

void MainWindow::delaytimerstop()
{
  tstop = true;
  delaytimer->stop();
}

QString MainWindow::mwatt2str(double d){
  QString qs="0.0 ";
  QString mh="";
  double w=0.0;
  bool g=true;

  if(g and d>1000000.0){w=d/1000000.0;mh="kW";g=false;}
  if(g and d>1000.0){w=d/1000.0;mh="W";g=false;}
  if(g and d>1){w=d;mh="mW";g=false;}
  if(g and d>0.001){w=d*1000.0;mh="uW";g=false;}
  if(g and d>0.000001){w=d*1000000.0;mh="nW";g=false;}
  if(g and d>0.000000001){w=d*1000000000.0;mh="pW";g=false;}
  if(g and d>0.000000000001){w=d*1000000000000.0;mh="fW";g=false;}
  if(g and d>0.000000000000001){w=d*1000000000000000.0;mh="aW";}

  if(w>100){
    qs = "%1 ";
    qs = qs.arg(w, 3,'f',1);
    //qs.sprintf("%3.1f ",w);
    return qs+mh;
  }
  if(w>10){
    qs = "%1 ";
    qs = qs.arg(w, 2,'f',2);
    //qs.sprintf("%2.2f ",w);
    return qs+mh;
  }
  if(w>1){
    qs = "%1 ";
    qs = qs.arg(w, 1,'f',3);
    //qs.sprintf("%1.3f ",w);
    return qs+mh;
  }
  return qs+mh;
}

QString MainWindow::volt2str(double d){
  QString qs="0.0 ";
  QString mh="";
  double w=0.0;
  bool g=true;

  if(g and d>1){w=d;mh="V";g=false;}
  if(g and d>0.001){w=d*1000.0;mh="mV";g=false;}
  if(g and d>0.000001){w=d*1000000.0;mh="uV";g=false;}
  if(g and d>0.000000001){w=d*1000000000.0;mh="nV";}

  if(w>100){
    qs = "%1 ";
    qs = qs.arg(w, 3,'f',1);
    //qs.sprintf("%3.1f ",w);
    return qs+mh;
  }
  if(w>10){
    qs = "%1 ";
    qs = qs.arg(w, 2,'f',2);
    //qs.sprintf("%2.2f ",w);
    return qs+mh;
  }
  if(w>1){
    qs = "%1 ";
    qs = qs.arg(w, 1,'f',3);
    //qs.sprintf("%1.3f ",w);
    return qs+mh;
  }
  return qs+mh;
}

void MainWindow::on_button_mfrq_clicked()
{
  QString qs;

  int i = ui->spinBox->value();
  qs = "@f%1;";
  qs = qs.arg(i,3,10, QLatin1Char('0')); //integer, 3 Stellen, basis 10, fuehrende 0'en
  //qs.sprintf("@f%03i;",i);
  //qDebug()<<qs;
  picmodem->writeLine(qPrintable(qs));
  ui->button_mfrq->setEnabled(false);
}

void MainWindow::on_button_att_clicked()
{
  QString qs;

  double d = ui->doubleSpinBox->value();
  d=d*10.0;
  qs = "@e%1;";
  qs = qs.arg(d, 3,'f',0, QLatin1Char('0'));
  //qs.sprintf("@e%03.0f;",d);
  //qDebug()<<qs;
  picmodem->writeLine(qPrintable(qs));
  ui->button_att->setEnabled(false);
}

void MainWindow::on_spinBox_valueChanged(int)
{
  ui->button_mfrq->setEnabled(true);
  //qDebug()<<"Spinbox geaendert";
}


void MainWindow::on_doubleSpinBox_valueChanged(double)
{
  ui->button_att->setEnabled(true);
  //qDebug()<<"DoubleSpinbox geaendert";
}

void MainWindow::readSettings()
{
  bool b;
  QSettings settings("AFU", "MinimWatt");

  QPoint pos = settings.value("pos", QPoint(200, 200)).toPoint();
  QSize size = settings.value("size", QSize(610, 510)).toSize();
  move(pos);
  resize(size);

  b = settings.value("tip", true).toBool();
  ui->actionTip->setChecked(b);
  tip(b);

#ifdef Q_OS_WIN
  srs232 = settings.value("rs232", QString("COM1")).toString();
#else
  srs232 = settings.value("rs232", QString("/dev/ttyUSB0")).toString();
#endif
  picmodem->closetty();
  if(!rs232isopen)rs232isopen = picmodem->opentty(srs232);
  if(rs232isopen){
    clrrxbuffer();
    picmodem->writeLine("@v;");
    bvantwort = true;
  }else{
    //warmstart();
  }
  idtty = 0; //mit Index 0 HW-Suche beginnen
  openttytimer->start(200); //des Geraetes
}

void MainWindow::writeSettings()
{
  bool b;

  QSettings settings("AFU", "MinimWatt");
  settings.setValue("pos", pos());
  settings.setValue("size", size());
  b = ui->actionTip->isChecked();
  settings.setValue("tip", b);
  if(bhwgefunden)settings.setValue("rs232", srs232);
}

void MainWindow::on_action_ber_QT_Mini_mW_Meter_triggered()
{
  QMessageBox::about(this, "PC Software-QT Mini mW-Meter", infotext);
}

void MainWindow::tip(bool atip){
  QString tip_attext = tr(
        "<b><u>Externes Leistungsd&auml;mpfungsglied</u></b> <br>"
        "<br>"
        "Wird ein D&auml;mpfungsglied vor dem Messeingang <br>"
        "geschaltet, z.B. Dummyload mit Messausgang, <br>"
        "kann hier der D&auml;mpfungswert eingestellt <br>"
        "werden. Der D&auml;mpfswert geht mit in die <br>"
        "Berechnung der Anzeigewerte ein."
        ,"tooltip text");
  QString tip_frqdb = tr(
        "<b><u>Korrektur Frequenzgang des AD8307</u></b><br>"
        "<br>"
        "Frequenzeingabe f&uuml;r die Korrektur des <br>"
        "Frequenzganges des AD8307. Der Messwert f&auml;llt<br>"
        " bis 500 MHz sehr stark ab.<br>"
        "Im Eeprom des PIC habe ich Korrekturpunkte<br>"
        "programmiert. Die Zwischenwerte werden duch <br>"
        "interpollieren berechnet. <br>"
        "Bei 10MHz betr&auml;gt die Abweichung 0,00 dB."
        ,"tooltip text");
  QString tip_nachkalib = tr(
        "<b><u>Info der Nachkalibrierung AD8307/AD8361</u></b><br>"
        "<br>"
        "Wir sehen die Nachkalibrierungswerte in dB.<br>"
        "Mit einem genauen Referenzpegel können wir<br>"
        "im mW-Wattmeter den AD8307 oder AD8361 wieder<br>"
        "genau auf 0,00 dBm kalibrieren. Eine umst&auml;ndliche<br>"
        "Neukalibrierung entf&auml;llt dadurch. So k&ouml;nnen wir<br>"
        "kleine Abweichungen schnell korrigieren. <u>Hier<br>"
        "werden nur die Abweichungen angezeigt.</u>"
        ,"tooltip text");
  QString tip_ad8307 = tr(
        "<b><u>Messwerte des AD8307</u></b><br>"
        "<br>"
        "Der AD8307 ist ein logaritmischer arbeitender IC.<br>"
        "Die dBm-Werte werden mit 2 Stellen nach dem Komma<br>"
        "angezeigt. Die Messdynamik betr&auml;gt etwa<br>"
        " -75dBm bis +10dBm.<br>"
        "Die dBm-Werte werden zus&auml;tzlich in Watt und Volt<br>"
        "umgerechnet.<br>"
        "<u>&Uuml;ber USB wird nur der dBm-Wert &uuml;bertragen.</u>"
        ,"tooltip text");
  QString tip_ad8361 = tr(
        "<b><u>Messwerte des AD8361</u></b><br>"
        "<br>"
        "Der AD8361 ist ein linear arbeitender IC. <br>"
        "Die Messdynamik betr&auml;gt nur etwa <br>"
        " -20dBm bis +10dBm. Daf&uuml;r ist die <br>"
        "Messaufl&ouml;sung sehr hoch. Deshalb können <br>"
        "die dBm-Werte auch mit 3 Stellen nach <br>"
        "dem Komma angezeigt werden. Tendenzen <br>"
        "kleinster Abweichungen sind gut erkennbar. <br>"
        "Messergebebnisse <u>kleiner -10dBm</u> sind ungenau <br>"
        "und werden deshalb nicht mehr dargestellt.<br>"
        "Die dBm-Werte werden zus&auml;tzlich in Watt und Volt<br>"
        "umgerechnet.<br>"
        "<u>&Uuml;ber USB wird nur der dBm-Wert &uuml;bertragen.</u>"
        ,"tooltip text");
  btip = atip;

  //qDebug()<<btip;
  if(btip){
    ui->gb_att_extern->setToolTip(tip_attext);
    ui->gb_messfrq->setToolTip(tip_frqdb);
    ui->gb_offset->setToolTip(tip_nachkalib);
    ui->gb_ad8307->setToolTip(tip_ad8307);
    ui->gb_ad8361->setToolTip(tip_ad8361);
  }else{
    ui->gb_att_extern->setToolTip("");
    ui->gb_messfrq->setToolTip("");
    ui->gb_offset->setToolTip("");
    ui->gb_ad8307->setToolTip("");
    ui->gb_ad8361->setToolTip("");
  }
}

void MainWindow::on_actionTip_triggered(bool checked)
{
  tip(checked);
}


void MainWindow::on_actionAD8307_triggered()
{
  QString qs;
  int i;
  QString nachkalib_ad8307 = tr(
        "<b><u>Nachkalibrieren des AD8307</u></b><br>"
        "<br>"
        "Am Messeingang eine genaue Pegelreferenz <br>"
        "0,00 dBm anschließen. <br>"
        "Das Nachkalibrieren funktioniert nur bei einer <br>"
        "Pegeldifferenz <u>kleiner 1 dB</u>. <br>"
        "Ist die Pegeldifferenz gr&ouml;&szlig;er 1 dB oder <br>"
        "wird keine Referenz angeschlossen, wird das <br>"
        "Offset auf 0,000 dB gesetzt. <br>"
        "<br>"
        "Die Nachkalibrierung dauert etwa 10 Sekunden!"
        ,"tooltip text");

  if(QMessageBox::information( this, tr("Nachkalibrieren","in Dialogbox")
                              ,nachkalib_ad8307,QMessageBox::Ok, QMessageBox::Abort )==QMessageBox::Ok){
    qs = "@n%1;";
    i=7;
    qs = qs.arg(i,2,10, QLatin1Char('0'));
    //qDebug()<<qs;
    picmodem->writeLine(qPrintable(qs));
  }
}


void MainWindow::on_actionAD8361_triggered()
{
  QString qs;
  int i;
  QString nachkalib_ad8361 = tr(
        "<b><u>Nachkalibrieren des AD8361</u></b><br>"
        "<br>"
        "Am Messeingang eine genaue Pegelreferenz <br>"
        "0,00 dBm anschließen. <br>"
        "Das Nachkalibrieren funktioniert nur bei einer <br>"
        "Pegeldifferenz <u>kleiner 1 dB</u>. <br>"
        "Ist die Pegeldifferenz gr&ouml;&szlig;er 1 dB oder <br>"
        "wird keine Referenz angeschlossen, wird das <br>"
        "Offset auf 0,000 dB gesetzt. <br>"
        "<br>"
        "Die Nachkalibrierung dauert etwa 10 Sekunden!"
        ,"tooltip text");

  if(QMessageBox::information( this, tr("Nachkalibrieren","in Dialogbox")
                              ,nachkalib_ad8361,QMessageBox::Ok, QMessageBox::Abort )==QMessageBox::Ok){
    qs = "@n%1;";
    i=61;
    qs = qs.arg(i,2,10, QLatin1Char('0'));
    //qDebug()<<qs;
    picmodem->writeLine(qPrintable(qs));
  }
}

